
# Slot: acted on behalf of




URI: [core:acted_on_behalf_of](https://w3id.org/linkml/tests/core/acted_on_behalf_of)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Agent](Agent.md)

## Parents


## Children


## Used by

 * [Agent](Agent.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | prov:actedOnBehalfOf |

